@@ -12,20 +12,16 @@ pub struct PartitionOffset {
 }
 
 impl PartitionOffset {
-    pub fn new(partition:i32,offset:i64)->Self{
-        Self{
-            partition,offset
-        }
+    pub fn new(partition: i32, offset: i64) -> Self {
+        Self { partition, offset }
     }
 }
 
-
 #[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct PartitionOffsets {
     pub(crate) partition_offsets: Vec<Option<PartitionOffset>>,
 }
 
-
 impl PartitionOffsets {
     pub fn new() -> Self {
         PartitionOffsets {
